***************************************************
***************************************************
***												***
*** Buying and Social Desirability Bias: 		***
*** Experimental Evidence from Nicaragua		***
***												***
*** AJPS										***
***												***
***************************************************
***************************************************


***************************************************
***************************************************
***												***
***			This dofile is to set up 			***
***		data file 2: Nicaragua_AJPS.dta 	 	***
***												***
***************************************************
***************************************************


*************************************************** 
* SET UP DOFILE 
*
* Use Data File: Nicaragua_AJPS.dta 
*
* Dofile structure:
* 	1) Basic Recoding
* 	2) Interaction Variables
* 	3) Party Follow ups
* 	4) Type of neighborhood goods
*
***************************************************


/*
* We recommend you to start by setting up your working directory
cd  "C:\yourWorkingDirectory\"

* Then, load the data
use "C:\yourWorkingDirectory\Nicaragua_AJPS.dta", clear
*/


**************************************************
* 1 BASIC RECODING 
**************************************************


* Generate PSU
	sort muni conse
	gen psu = (_n - (mod(_n-1, 12)+1))+1
	label variable psu "PSU"
	svyset psu 
	label var psu "psu"

* Welfare Beneficiary
	tab p1
	tab p1, nolabel
	gen welfare=p1
	replace welfare=0 if p1==2
	tab welfare
	label var welfare "Welfare Beneficiary"

* Public works beneficiary
	tab p2
	tab p2,nolabel
	gen pubwrk=p2
	replace pubwrk=0 if p2==2
	replace pubwrk=. if p2==8 | p2==9
	tab pubwrk
	label var pubwrk "Public works beneficiary"

* List experiment (number of tiems reported)
	tab p3 
		replace p3=. if p3==88
	tab p3b
		replace p3b=. if p3b==88
	gen list=p3 if p3~=.
	replace list=p3b if p3b~=.
	tab list
	label var list "List experiment"


* Treatment variable (1=treatment, 0=control)
	gen treatment=0
	replace treatment=1 if p3~=.
	replace treatment=. if p3==. & p3b==.
	tab treatment
	label var treatment "treatment"


* Neighborhood vote buying
	tab p4
	tab p4,nolabel
	gen neigift=p4
	replace neigift=0 if p4==2
	replace neigift=. if p4==8 
	label var neigift "Neighborhood vote buying"


* Neighborhood gift influenced peoples' vote 
	tab p8
	tab p8,nolabel
	replace p8=0 if p8==2
	replace p8=. if p8==8 | p8==9 | p8==88
	label var p8 "Neighborhood gift influence"

* Individual vote buying
	tab p9
	tab p9,nolabel
	gen indgift=p9
	replace indgift=0 if p9==2
	replace indgift=. if p9==8 | p9==9 
	label var indgift "Individual vote buying"

*  Individual gift influenced peoples' vote 
	tab p13
	tab p13,nolabel
	replace p13=0 if p13==2
	replace p13=. if p13==88 | p13==9 
	label var p13 "Individual gift influence"

* Monitor (droping DK & NA)
	tab p14
	tab p14,nolabel
	gen monitor=p14
	replace monitor=0 if p14==2
	replace monitor=. if p14==8 | p14==9 
	tab monitor
	label var monitor "Monitor (droping DK & NA)"

* Monitor B (three categories "Yes" "No" "DK/NA")
	gen monitorb=p14
	recode monitorb (1=3) (8=1) (9=1)
	label define monitorb 1 "NA/DK" 2 "No" 3 "Yes"
	label value monitorb monitorb 
	tab monitorb
	label var monitorb "Monitor B (three categories)"

* Monitor C (dummy var 1="Yes, DK, NA" & 0="No")
	gen monitorc=p14
	recode monitorc (8=1) (9=1) (2=0)
	label define monitorc 1 "Yes, DK, NA" 0 "No"
	label value monitorc monitorc
	tab monitorc
	label var monitorc "Monitor C (dummy var 1=Yes DK NA / 0=No)"

* Ever attended a Citizen Power Council
	tab p15
	tab p15,nolabel
	gen councild=0
	replace councild=1 if p15==1 | p15==2 | p15==3
	tab councild
	label var councild "Ever attended CPC"

* Party affiliation
	tab p31
	tab p31,nolabel
	gen partyid=p31 
	tab partyid 
	label var partyid "Party ID"

* Voted 
	tab p32
	tab p32,nolabel
	gen voted=p32
	tab voted
	label var voted "Voted "

* Voted (DK/NA = 0)
	tab p32
	tab p32, nolabel
	gen votedb=0
	replace votedb=1 if p32>0 & p32<99
	label var votedb "Voted (DK/NA = 0)"

* Voted (DK/NA as missing)
	tab p32
	tab p32, nolabel
	gen votedb2=0
	replace votedb2=1 if p32>0 & p32<99
	replace votedb2=. if p32==99
	label var votedb2 "Voted (DK/NA as missing)"

* Clean elections
	tab p33
	tab p33,nolabel
	gen cleanele=p33
	replace cleanele=0 if p33==2
	replace cleanele=. if p33==8 | p33==9 
	tab cleanele
	label var cleanele "Clean elections"

* Female
	tab p200
	tab p200,nolabel
	gen female=p200
	recode female (2=1) (1=0)
	label define female 0 "male" 1 "female"
	label value female female
	tab female
	label var female "Fenale"

* Age
	tab p201
	tab p201,nolabel
	gen age=p201
	label val age p201 
	tab age
	label var age "Age"

* Education
	gen edu=p202
	label var edu "Education"

* Income (DK/NA as missing)
	tab p203a
	tab p203a,nolabel
	gen income=p203a
	replace income=. if p203a==9
	tab income
	label var income "Income (DK/NA as missing)"

* Income (DK/NA=0)
	tab p203a
	tab p203a,nolabel
	gen incomeb=p203a
	replace incomeb=0 if p203a==9
	tab incomeb
	label var incomeb "Income (DK/NA=0)"

* Generate income 1=No Answer income question
	gen incomeNA=0
	replace incomeNA=1 if p203a==9
	tab incomeNA
	label var incomeNA "No answer income"

* Party ID Independents
	tab p31
	tab p31, nolabel
	generate none=0
	replace  none=1 if p31==0
	tab none
	label var none "PID Independents"

* Party ID Independents and NA/DK
	generate noneb=0
	replace  noneb=1 if p31==0 | p31==99
	tab noneb
	label var noneb "PID Independents and NA/DK" 

* Party ID FSLN
	generate fsln=0
	replace  fsln=1 if p31==1
	label var fsln "PID FSLN"

* Party ID PLC
	generate plc=0
	replace  plc=1 if p31==2
	label var plc "PID PLC"

* Party ID ALN
	generate aln=0
	replace  aln=1 if p31==3
	label var aln "PID ALN"

* Party ID MRS
	generate mrs=0
	replace  mrs=1 if p31==4
	label var mrs "PID MRS"

* Party ID AC
	generate ac=0
	replace  ac=1 if p31==5
	label var ac "PID AC"

* Party ID PRN
	generate prn=0
	replace  prn=1 if p31==6
	label var prn "PID PRN"

* VOTE CHOICE
	generate vote_party=p32
	replace vote_party=3 if p32>=3
	label define vote_party 0 "none" 1 "PLC" 2 "FSLN" 3 "OTHER"
	label value vote_party vote_party
	tab vote_party
	label var vote_party "Vote Choice"

* Zone
	tab zona
	tab zona, nolabel
	replace zona=0 if zona==2
	label var zona "Urban"



***********************************
** 2 GENERATE INTERACTION VARIABLES
***********************************



* PARTIES (Interaction)
	gen I_fsln=treatment*fsln
	gen I_plc=treatment*plc

* INCOME [based on "incomeb" Income (DK/NA=0)] (Interaction)
	tab incomeb, gen(inc_)
	label variable inc_1 "Income No Answer"
	label variable inc_2 "Very Poor"
	label variable inc_3 "Poor"
	label  variable inc_4 "Middle/upper income"

	gen I_inc_2=treatment*inc_2
	gen I_inc_3=treatment*inc_3
	gen I_inc_4=treatment*inc_4
	gen I_incNA=treatment*inc_1

* EDUCATION (Interaction)
	gen edu3=edu
	replace edu3=1 if edu==0
	tab edu3, gen (edu_)
	label var edu3 "Education three categories"
	label variable edu_1 "Primary or less"
	label variable edu_2 "Secondary"
	label variable edu_3 "University"

	gen I_edu3=treatment*edu3
	gen I_edu=treatment*edu
	gen I_primary=treatment*edu_1
	gen I_secondary=treatment*edu_2
	gen I_univ=treatment*edu_3

* AGE (Interaction)
	tab age, gen(age_)
	gen I_young=treatment*age_1
	gen I_middle=treatment*age_2
	gen I_old=treatment*age_3
	gen I_age=treatment*age

* MALE (Interaction)
	gen male=0
	replace male=1 if female==0

	gen I_female=treatment*female
	gen I_male=treatment*male

* MONITOR (Interaction)
	gen Ymonitor=0
	replace Ymonitor=1 if monitor==1
	label var Ymonitor "Monitor Yes"

	gen DKmonitor=0
	replace DKmonitor=1 if monitor==.
	label var DKmonitor "Monitor DK"

	gen YDKmonitor=0
	replace YDKmonitor=1 if monitor==1 | monitor==.
	label var YDKmonitor "Monitor Yes, DK"

	gen I_Ymonitor=treatment*Ymonitor
	gen I_DKmonitor=treatment*DKmonitor
	gen I_YDKmonitor=treatment*YDKmonitor

	gen I_monitor=treatment*monitor


* WELFARE BENEFICIARY (Interaction)
	gen I_welfare=treatment*welfare

* PULBIC WORKS BENEFICIARY (Interaction)
	gen I_pubwrk=treatment*pubwrk

* CITIZEN POWER COUNCILS (Interaction)
	gen I_councild=treatment*councild

* URBAN (Interaction)
	gen I_urban=treatment*zona




*************************************
** 3 PARTY FOLLOW UPS
*************************************


***neighborhood gift party follow up
gen neigPLC=0
	replace neigPLC=1 if p7a==1 | p7b==1 | p7c==1
	replace neigPLC=. if p7a==88
	label variable neigPLC "PLC Gift in Neighborhood"

gen neigFSLN=0
	replace neigFSLN=1 if p7a==2 | p7b==2 | p7c==2
	replace neigFSLN=. if p7a==88
	label variable neigFSLN "FSLN Gift in Neighborhood"

gen neigOther=0
	replace neigOther =1 if p7a==3 | p7b==3 | p7c==3
	replace neigOther =1 if p7a==4 | p7b==4 | p7c==4
	replace neigOther =. if p7a==88
	label variable neigOther "Other Party Gift in Neighborhood"

gen neigNA=0
	replace neigNA=1 if neigPLC==0 & neigFSLN==0 & neigOther==0
	replace neigNA=. if p7a==88
	label variable neigNA "No answer Party Gift in Neighborhood"


***individual gift party follow up
gen indPLC=0
	replace indPLC=1 if p12a==1 | p12b==1 | p12c==1
	replace indPLC=. if p12a==88
	label variable indPLC "PLC Inidividual Gift"

gen indFSLN=0
	replace indFSLN=1 if p12a==2 | p12b==2 | p12c==2
	replace indFSLN=. if p12a==88
	label variable indFSLN "FSLN Individual Gift"

gen indOther=0
	replace indOther =1 if p12a==3 | p12b==3 | p12c==3
	replace indOther =1 if p12a==4 | p12b==4 | p12c==4
	replace indOther =. if p12a==88
	label variable indOther "Other Party Individual Gift"

gen indNA=0
	replace indNA=1 if indPLC==0 & indFSLN==0 & indOther==0
	replace indNA=. if p12a==88
	label variable indNA "No answer Party Individual Gift"


	
********************************
* 4 TYPE OF NEIGHBORHOOD GOODS
********************************

label define type 1 "bike or motorcycle" 2 "cattle" 3 "clothing" 4 "favor" 5 "food" 6 "fuel" 7 "furniture" 8 "housing" 9 "medicine" 10 "money" 11 "other private goods" 12 "tools or construction materials"

gen type_1=.
	replace type_1=	1	 if p5a==	31
	replace type_1=	1	 if p5a==	33
	replace type_1=	2	 if p5a==	18
	replace type_1=	2	 if p5a==	23
	replace type_1=	2	 if p5a==	4
	replace type_1=	2	 if p5a==	42
	replace type_1=	2	 if p5a==	22
	replace type_1=	2	 if p5a==	16
	replace type_1=	3	 if p5a==	11
	replace type_1=	3	 if p5a==	12
	replace type_1=	3	 if p5a==	24
	replace type_1=	3	 if p5a==	52
	replace type_1=	4	 if p5a==	13
	replace type_1=	4	 if p5a==	44
	replace type_1=	4	 if p5a==	51
	replace type_1=	4	 if p5a==	10
	replace type_1=	5	 if p5a==	3
	replace type_1=	5	 if p5a==	35
	replace type_1=	5	 if p5a==	25
	replace type_1=	5	 if p5a==	21
	replace type_1=	5	 if p5a==	27
	replace type_1=	5	 if p5a==	38
	replace type_1=	5	 if p5a==	20
	replace type_1=	5	 if p5a==	46
	replace type_1=	6	 if p5a==	8
	replace type_1=	6	 if p5a==	15
	replace type_1=	7	 if p5a==	29
	replace type_1=	7	 if p5a==	9
	replace type_1=	7	 if p5a==	1
	replace type_1=	8	 if p5a==	2
	replace type_1=	9	 if p5a==	41
	replace type_1=	10	 if p5a==	7
	replace type_1=	11	 if p5a==	5
	replace type_1=	11	 if p5a==	26
	replace type_1=	11	 if p5a==	45
	replace type_1=	11	 if p5a==	30
	replace type_1=	11	 if p5a==	37
	replace type_1=	11	 if p5a==	17
	replace type_1=	11	 if p5a==	47
	replace type_1=	11	 if p5a==	28
	replace type_1=	11	 if p5a==	48
	replace type_1=	12	 if p5a==	34
	replace type_1=	12	 if p5a==	19
	replace type_1=	12	 if p5a==	50
	replace type_1=	12	 if p5a==	36
	replace type_1=	12	 if p5a==	32
	replace type_1=	12	 if p5a==	6
	replace type_1=	12	 if p5a==	39
	replace type_1=	12	 if p5a==	40
	replace type_1=	12	 if p5a==	49
	replace type_1=	12	 if p5a==	14

	label val type_1 type
	label var type_1 "Type of good 1"



gen type_2=.
	replace type_2=	1	 if p5b==	31
	replace type_2=	1	 if p5b==	33
	replace type_2=	2	 if p5b==	18
	replace type_2=	2	 if p5b==	23
	replace type_2=	2	 if p5b==	4
	replace type_2=	2	 if p5b==	42
	replace type_2=	2	 if p5b==	22
	replace type_2=	2	 if p5b==	16
	replace type_2=	3	 if p5b==	11
	replace type_2=	3	 if p5b==	12
	replace type_2=	3	 if p5b==	24
	replace type_2=	3	 if p5b==	52
	replace type_2=	4	 if p5b==	13
	replace type_2=	4	 if p5b==	44
	replace type_2=	4	 if p5b==	51
	replace type_2=	4	 if p5b==	10
	replace type_2=	5	 if p5b==	3
	replace type_2=	5	 if p5b==	35
	replace type_2=	5	 if p5b==	25
	replace type_2=	5	 if p5b==	21
	replace type_2=	5	 if p5b==	27
	replace type_2=	5	 if p5b==	38
	replace type_2=	5	 if p5b==	20
	replace type_2=	5	 if p5b==	46
	replace type_2=	6	 if p5b==	8
	replace type_2=	6	 if p5b==	15
	replace type_2=	7	 if p5b==	29
	replace type_2=	7	 if p5b==	9
	replace type_2=	7	 if p5b==	1
	replace type_2=	8	 if p5b==	2
	replace type_2=	9	 if p5b==	41
	replace type_2=	10	 if p5b==	7
	replace type_2=	11	 if p5b==	5
	replace type_2=	11	 if p5b==	26
	replace type_2=	11	 if p5b==	45
	replace type_2=	11	 if p5b==	30
	replace type_2=	11	 if p5b==	37
	replace type_2=	11	 if p5b==	17
	replace type_2=	11	 if p5b==	47
	replace type_2=	11	 if p5b==	28
	replace type_2=	11	 if p5b==	48
	replace type_2=	12	 if p5b==	34
	replace type_2=	12	 if p5b==	19
	replace type_2=	12	 if p5b==	50
	replace type_2=	12	 if p5b==	36
	replace type_2=	12	 if p5b==	32
	replace type_2=	12	 if p5b==	6
	replace type_2=	12	 if p5b==	39
	replace type_2=	12	 if p5b==	40
	replace type_2=	12	 if p5b==	49
	replace type_2=	12	 if p5b==	14

	label val type_2 type
	label var type_2 "Type of good 2"	



gen type_3=.	
	replace type_3=	1	 if p5c==	31
	replace type_3=	1	 if p5c==	33
	replace type_3=	2	 if p5c==	18
	replace type_3=	2	 if p5c==	23
	replace type_3=	2	 if p5c==	4
	replace type_3=	2	 if p5c==	42
	replace type_3=	2	 if p5c==	22
	replace type_3=	2	 if p5c==	16
	replace type_3=	3	 if p5c==	11
	replace type_3=	3	 if p5c==	12
	replace type_3=	3	 if p5c==	24
	replace type_3=	3	 if p5c==	52
	replace type_3=	4	 if p5c==	13
	replace type_3=	4	 if p5c==	44
	replace type_3=	4	 if p5c==	51
	replace type_3=	4	 if p5c==	10
	replace type_3=	5	 if p5c==	3
	replace type_3=	5	 if p5c==	35
	replace type_3=	5	 if p5c==	25
	replace type_3=	5	 if p5c==	21
	replace type_3=	5	 if p5c==	27
	replace type_3=	5	 if p5c==	38
	replace type_3=	5	 if p5c==	20
	replace type_3=	5	 if p5c==	46
	replace type_3=	6	 if p5c==	8
	replace type_3=	6	 if p5c==	15
	replace type_3=	7	 if p5c==	29
	replace type_3=	7	 if p5c==	9
	replace type_3=	7	 if p5c==	1
	replace type_3=	8	 if p5c==	2
	replace type_3=	9	 if p5c==	41
	replace type_3=	10	 if p5c==	7
	replace type_3=	11	 if p5c==	5
	replace type_3=	11	 if p5c==	26
	replace type_3=	11	 if p5c==	45
	replace type_3=	11	 if p5c==	30
	replace type_3=	11	 if p5c==	37
	replace type_3=	11	 if p5c==	17
	replace type_3=	11	 if p5c==	47
	replace type_3=	11	 if p5c==	28
	replace type_3=	11	 if p5c==	48
	replace type_3=	12	 if p5c==	34
	replace type_3=	12	 if p5c==	19
	replace type_3=	12	 if p5c==	50
	replace type_3=	12	 if p5c==	36
	replace type_3=	12	 if p5c==	32
	replace type_3=	12	 if p5c==	6
	replace type_3=	12	 if p5c==	39
	replace type_3=	12	 if p5c==	40
	replace type_3=	12	 if p5c==	49
	replace type_3=	12	 if p5c==	14

	label val type_3 type
	label var type_3 "Type of good 3"


