***************************************************
***************************************************
***												***
*** Buying and Social Desirability Bias: 		***
*** Experimental Evidence from Nicaragua		***
***												***
*** AJPS										***
***												***
***************************************************
***************************************************


********************************************************************************************* 
* TABLES DOFILE
*
* Data File 2: Nicaragua_AJPS.dta 
*
* Dofile structure:
* 	TABLE 2: Vote Buying, Direct and Unobtrusive Measures 
* 	TABLE 3: Reports of Vote Buying in Important Sub-Populations
* 		Column 1 and 2: Groups and sub-groups
* 		Column 3: Proportion of the Sample
* 		Column 4: List Experiment Estimate
*		Column 5: Individual Estimate
* 		Column 6: Neighborhood Estimate
* 	TABLE 4: Comparing Vete Buying Models Using Direct Measures and the List Experiment
*
*********************************************************************************************


	
*******************************************************
*******************************************************
***	 	         For TABLES 2-4 use  			 	***
***			data file 2: Nicaragua_AJPS.dta 	 	***
***													***
***		Make sure you run the "1 - Setup" dofile 	***
*** on this database before replicating the tables 	***
*******************************************************
*******************************************************

/*Load the data:
use "C:\yourWorkingDirectory\Nicaragua_AJPS.dta", clear
*/

* Survey set
svyset psu


***************************************************
* TABLE 2 
* Vote Buying, Direct and Unobtrusive measures
***************************************************

* COLUMN 1: List Experiment
	sum list if treatment==0	
	sum list if treatment==1
	
	svy: regress list treatment

* COLUMN 2: Individual gifts
	svy: proportion indgift

	*Z-test for List Experiment proportion vs Individual proportion
		di (abs(.2433535-.0239282))/(sqrt((.0552721)^2 + (.0057769)^2))
		di (1-normal(3.9484033))*2  

* COLUMN 3: Neighborhood gifts
	svy: proportion neigift
	
	*Z-test for List Experiment proportion vs Neighobrood proportion
		di (abs(.2433535-.1783567))/(sqrt((.0552721)^2 + (.01798)^2))
		di (1-normal(1.1182626))*2

	/*	NOTE TABLE 2:
	List experiment control and treatment values 
	are the mean number of items identified by respondents.  
	The numbers of subjects in each condition are in brackets. 
	Linearized standard errors adjusted for the survey 
	design are in parentheses.
	*** p<.01 for difference between list experiment proportion 
	and the direct individual proportion.  
	The difference between the list and neighborhood proportions 
	is not statistically significant.  Tests are two-tailed 
	difference of proportions tests.
	*/




***************************************************
* TABLE 3 
* Reports of Vote Buying in Important Sub-Populations
***************************************************

************************
*COLUMN 1: Group label
*COLUMN 2: Sub-group label
************************

**************************************************     
*COLUMN 3: Proportion of the group in the sample
**************************************************     
* Political
	svy: proportion  votedb 
	svy: proportion  fsln 
	svy: proportion  plc 
	svy: proportion  noneb  
* Welfare and Public Works
	svy: proportion  welfare 
	svy: proportion  pubwrk 
* Citizen Power Councils
	svy: proportion  councild
* Monitor  
	svy: proportion  monitorb
* Income
	svy: proportion  incomeb 
* Education
	svy: proportion  edu 
* Age
	svy: proportion  age 
* Gender
	svy: proportion  female 
* Zone
	svy: proportion  zona




***************************************************************************    
* COLUMN 4: List experiment proportion by subgroups
*
* Statistical significance is denoted by "*" in the paper
***************************************************************************    
* Political
	svy: reg list treatment if votedb==1
	svy: reg list treatment if votedb==0
	svy: reg list treatment if fsln==1
	svy: reg list treatment if plc==1
	svy: reg list treatment if noneb==1
* Welfare and Public Works
	svy: reg list treatment if welfare==1	
	svy: reg list treatment if welfare==0
	svy: reg list treatment if pubwrk==1
	svy: reg list treatment if pubwrk==0
* Citizen Power Councils
	svy: reg list treatment if councild==1	
	svy: reg list treatment if councild==0
* Monitor  
	svy: reg list treatment if monitorb==3	
	svy: reg list treatment if monitorb==2
	svy: reg list treatment if monitorb==1
* Income
	svy: reg list treatment if incomeb==1	
	svy: reg list treatment if incomeb==2
	svy: reg list treatment if incomeb==3
	svy: reg list treatment if incomeb==0
* Education
	svy: reg list treatment if edu==0	 
	svy: reg list treatment if edu==1
	svy: reg list treatment if edu==2
	svy: reg list treatment if edu==3
* Age
	svy: reg list treatment if age==1
	svy: reg list treatment if age==2
	svy: reg list treatment if age==3
* Gender
	svy: reg list treatment if female==1	
	svy: reg list treatment if female==0
* Zone
	svy: reg list treatment if zona==0
	svy: reg list treatment if zona==1



*********************************************************************************** 
* COLUMN 5: proportion of individual gifts by sub-groups
*
* After estimating the proportion individual gifts we calculate the difference
* between the list expeirment estimante and the proportion of individual gifts
* Statistical significance of the differenceis denoted by daggers in the paper
*********************************************************************************** 
* Political
	svy: proportion  indgift if votedb==1
		di (abs(.2288034 -.0266876))/(sqrt((.0891219)^2 + (.0076019)^2))
		di (1-normal(2.2596525))*2  
	svy: proportion  indgift if votedb==0
		di (abs(.2751781 -.0191257))/(sqrt((.1067029)^2 + (.0079183)^2))
		di (1-normal(2.3930958))*2  
	svy: proportion  indgift if fsln==1
		di (abs(.2093321 -.044665))/(sqrt((.1084803)^2 + (.0116154)^2))
		di (1-normal(1.5093174))*2 
	svy: proportion  indgift if plc==1
		di (abs(.3264912 -.0095694))/(sqrt((.1564703)^2 + (.0066091)^2))
		di (1-normal(2.0236394))*2  	
	svy: proportion  indgift if noneb==1
		di (abs(.2615584 -.0106383))/(sqrt((.1019556)^2 + (.006365)^2))
		di (1-normal(2.4562904))*2 
* Welfare and Public Works
	svy: proportion  indgift if welfare==1
		di (abs(.1 -.1891892))/(sqrt((.2787903)^2 + (.0524627)^2))
		di (1-normal(.31439678))*2 
	svy: proportion  indgift if welfare==0
		di (abs(.2473823 -.0107643))/(sqrt((.0581666)^2 + (.0041712)^2))
		di (1-normal(4.0575164))*2  
	svy: proportion  indgift if pubwrk==1
		di (abs(.2203612 -.0419753))/(sqrt((.094296)^2 + (.0113054)^2))
		di (1-normal(1.8783138))*2  
	svy: proportion  indgift if pubwrk==0
		di (abs(.2457673 -.0119048))/(sqrt((.0829844)^2 + (.0064133)^2))
		di (1-normal(2.8097717))*2  
* Citizen Power Councils
	svy: proportion  indgift if councild==1
		di (abs(.4827236 -.0494505))/(sqrt((.1647234)^2 + (.0178692)^2))
		di (1-normal(2.6149656))*2 
	svy: proportion  indgift if councild==0
		di (abs(.1899528 -.0182704))/(sqrt((.0697234)^2 + (.0057611)^2))
		di (1-normal(2.4539726))*2  	
* Monitor  
	svy: proportion  indgift if monitorb==3
		di (abs(.4916226 -.0139276))/(sqrt((.1140222)^2 + (.0060994)^2))
		di (1-normal(4.1835099))*2 
	svy: proportion  indgift if monitorb==2
		di (abs(.0629117 -.0289855))/(sqrt((.0854212)^2 + (.0075018 )^2))
		di (1-normal(.39564093))*2  
	svy: proportion  indgift if monitorb==1
		di (abs(.4015152 -.0326087))/(sqrt((.2113547)^2 + (.0177888)^2))
		di (1-normal(1.7392883))*2  
* Income
	svy: proportion  indgift if incomeb==1
		di (abs(.2311426 -.0430622))/(sqrt((.1537433)^2 + (.0430622)^2))
		di (1-normal(1.1780048))*2  
	svy: proportion  indgift if incomeb==2
		di (abs(.2634563 -.0238095))/(sqrt((.1022136)^2 + (.0072942)^2))
		di (1-normal(2.3386214))*2 
	svy: proportion  indgift if incomeb==3
		di (abs(.1421569 -.0152672))/(sqrt((.1400015)^2 + (.0092865)^2))
		di (1-normal(.90435795))*2  
	svy: proportion  indgift if incomeb==0  
			di (abs(.5210084 -0))/(sqrt((.2542788)^2 + (0)^2))
			di (1-normal(2.0489652))*2  
* Education
	svy: proportion  indgift if edu==0
		di (abs(.1605442 -.03125))/(sqrt((.1796662)^2 + (.0173164)^2))
		di (1-normal(.71631629))*2 
	svy: proportion  indgift if edu==1
		di (abs(.2094853 -.0350877))/(sqrt((.1076836)^2 + (.0112208)^2))
		di (1-normal(1.6108158))*2  
	svy: proportion  indgift if edu==2
		di (abs(.2665816 -.014218))/(sqrt((.1011726)^2 + (.0056849)^2))
		di (1-normal(2.4904583))*2 
	svy: proportion  indgift if edu==3
		di (abs(.3735772 -.020979))/(sqrt((.1929916)^2 + (.0117477)^2))
		di (1-normal(1.8236377))*2  
* Age
	svy: proportion  indgift if age==1
		di (abs(.0705817 -.0333333))/(sqrt((.1008478)^2 + (.0118157)^2))
		di (1-normal(.36684332))*2  
	svy: proportion  indgift if age==2
		di (abs(.2973037 -.0153453))/(sqrt((.1078407)^2 + (.0061815)^2))
		di (1-normal(2.6102977))*2  
	svy: proportion  indgift if age==3
		di (abs(.412664 -.0238095))/(sqrt((.1309808)^2 + (.0092263)^2))
		di (1-normal(2.9614521))*2  
* Gender
	svy: proportion  indgift if female==1
		di (abs(.3323771 -.0217391))/(sqrt((.1050618)^2 + (.0073264)^2))
		di (1-normal(2.949554))*2 
	svy: proportion  indgift if female==0
		di (abs(.1528324 -.0261569))/(sqrt((.0896629)^2 + (.0067118)^2))
		di (1-normal(1.4088556))*2  	
* Zone
	svy: proportion  indgift if zona==0
		di (abs(.2554348 -.0296496))/(sqrt((.0802235)^2 + (.0099082)^2))
		di (1-normal(2.7932287))*2  
	svy: proportion  indgift if zona==1
		di (abs(.2364769 -.0205696))/(sqrt((.0747863)^2 + (.0071179)^2))
		di (1-normal(2.8740022))*2  




*********************************************************************************** 
*COLUMN 6: proportion of neighborhood gifts in sub-group
*
* After estimating the proportion neighborhood gifts we calculate the difference
* between the list expeirment estimante and the proportion of neighborhood gifts
* Statistical significance of the differenceis denoted by "" in the paper
*********************************************************************************** 
* Political
	svy: proportion  neigift if votedb==1
		di (abs(.2288034 -.2))/(sqrt((.0891219)^2 + (.0212362)^2))
		di (1-normal(.31438898))*2  
	svy: proportion  neigift if votedb==0
		di (abs(.2751781 -.1404959))/(sqrt((.1067029)^2 + (.020838)^2))
		di (1-normal(1.2388149))*2  
	svy: proportion  neigift if fsln==1
		di (abs(.2093321 -.1820449))/(sqrt((.1084803)^2 + (.0270773)^2))
		di (1-normal(.24405286))*2  
	svy: proportion  neigift if plc==1
		di (abs(.3264912 -.247619))/(sqrt((.1564703)^2 + (.0335939)^2))
		di (1-normal(.49284052))*2  
	svy: proportion  neigift if noneb==1
		di (abs(.2615584 -.1313673))/(sqrt((.1019556)^2 + (.0206184)^2))
		di (1-normal(1.2516025))*2 
* Welfare and Public Works
	svy: proportion  neigift if welfare==1
		di (abs(.1 -.2702703))/(sqrt((.2787903)^2 + (.0523566)^2))
		di (1-normal(.60025354))*2 
	svy: proportion  neigift if welfare==0
		di (abs(.2473823 -.1709957))/(sqrt((.0581666)^2 + (.0183009)^2))
		di (1-normal(1.2526979))*2  
	svy: proportion  neigift if pubwrk==1
		di (abs(.2203612 -.2437811))/(sqrt((.094296)^2 + (.0281158)^2))
		di (1-normal(.23801112))*2
	svy: proportion  neigift if pubwrk==0
		di (abs(.2457673 -.1362862))/(sqrt((.0829844)^2 + (.0180108)^2))
		di (1-normal(1.2892806))*2  	
* Citizen Power Councils
	svy: proportion  neigift if councild==1
		di (abs(.4827236 -.1978022))/(sqrt((.1647234)^2 + (.0377744)^2))
		di (1-normal(1.6859342))*2  
	svy: proportion  neigift if councild==0
		di (abs(.1899528 -.1740196))/(sqrt((.0697234)^2 + (.0181186)^2))
		di (1-normal(.22117424))*2  
* Monitor  
	svy: proportion  neigift if monitorb==3
		di (abs(.4916226 -.198324))/(sqrt((.1140222)^2 + (.0267205)^2))
		di (1-normal(2.5044441))*2 
	svy: proportion  neigift if monitorb==2
		di (abs(.0629117 -.1602914))/(sqrt((.0854212)^2 + (.0215377)^2))
		di (1-normal(1.1053995))*2  
	svy: proportion  neigift if monitorb==1
		di (abs(.4015152 -.2087912))/(sqrt((.2113547)^2 + (.0435218)^2))
		di (1-normal(.89311257))*2  
* Income
	svy: proportion  neigift if incomeb==1
		di (abs(.2311426 -.1634615))/(sqrt((.1537433)^2 + (.0305106)^2))
		di (1-normal(.43180076))*2  
	svy: proportion  neigift if incomeb==2
		di (abs(.2634563 -.1721133))/(sqrt((.1022136)^2 + (.0245927)^2))
		di (1-normal(.86885352))*2 
	svy: proportion  neigift if incomeb==3
		di (abs(.1421569 -.2222222))/(sqrt((.1400015)^2 + (.0309319)^2))
		di (1-normal(.55842175))*2 
	svy: proportion  neigift if incomeb==0
		di (abs(.5210084 -.1))/(sqrt((.2542788)^2 + (.0391454)^2))
		di (1-normal(1.6364183))*2  
* Education
	svy: proportion  neigift if edu==0
		di (abs(.1605442 -.1505376))/(sqrt((.1796662)^2 + (.0466434)^2))
		di (1-normal(.05390846))*2 
	svy: proportion  neigift if edu==1
		di (abs(.2094853 -.1583578))/(sqrt((.1076836)^2 + (.0228343)^2))
		di (1-normal(.46446617))*2 
	svy: proportion  neigift if edu==2
		di (abs(.2665816 -.2))/(sqrt((.1011726)^2 + (.0250484)^2))
		di (1-normal(.63881189))*2
	svy: proportion  neigift if edu==3
		di (abs(.3735772 -.1805556))/(sqrt((.1929916)^2 + (.0417168)^2))
		di (1-normal(.97757773))*2 
* Age
	svy: proportion  neigift if age==1
		di (abs(.0705817 -.2027778))/(sqrt((.1008478)^2 + (.0328129)^2))
		di (1-normal(1.2465249))*2 
	svy: proportion  neigift if age==2
		di (abs(.2973037 -.1717949))/(sqrt((.1078407)^2 + (.0230694)^2))
		di (1-normal(1.1380858))*2
	svy: proportion  neigift if age==3
		di (abs(.412664 -.1532258))/(sqrt((.1309808)^2 + (.0232927)^2))
		di (1-normal(1.9501385))*2  
* Gender
	svy: proportion  neigift if female==1
		di (abs(.3323771 -.1547619))/(sqrt((.1050618)^2 + (.0212453)^2))
		di (1-normal(1.6570381))*2 
	svy: proportion  neigift if female==0
		di (abs(.1528324 -.2024291))/(sqrt((.0896629)^2 + (.0214404)^2))
		di (1-normal(.53797939))*2
* Zone
	svy: proportion  neigift if zona==0
		di (abs(.2554348 -.1891892))/(sqrt((.0802235)^2 + (.0334991)^2))
		di (1-normal(.7619976))*2 
	svy: proportion  neigift if zona==1
		di (abs(.2364769 -.1719745))/(sqrt((.0747863)^2 + (.0208671)^2))
		di (1-normal(.83075677))*2 

	/* NOTE TABLE 3:
	Linearized Standard Errors are in parentheses and are adjusted for the survey design.  
	* Denotes the statistical significance of the estimated difference between treatment 
	and control groups according to the list experiment (* p<0.1, ** p<0.05, *** p <0.01).
	  Denotes the statistical significance of the difference between the estimated 
	proportion of vote buying according to the list experiment and the proportion of 
	respondents directly reporting individual gifts ( p<0.1,  p<0.05,  p <0.01).
	 Denotes the statistical significance of the difference between the estimated proportion 
	of vote buying according to the list experiment and the proportion of respondents directly 
	reporting vote buying in their neighborhood ( p<0.1,  p<0.05).
	*/
		
		
		
		
		
***************************************************
* TABLE 4 
* Comparing Vote Buying Models Using Direct 
* Measures and the List Experiment
***************************************************		
	


* Model 1
svy: logit  indgift fsln plc inc_2 inc_3 edu age female, nolog
estimates store m11

* Model 2
svy: logit  indgift fsln plc inc_2 inc_3 edu age female YDKmonitor  welfare pubwrk councild zona, nolog
estimates store m12

* Model 3
svy: logit  neigift fsln plc inc_2 inc_3 inc_4 edu age female, nolog
estimates store m13

* Model 4
svy: logit  neigift fsln plc inc_2 inc_3 inc_4 edu age female YDKmonitor  welfare pubwrk councild zona, nolog
estimates store m14

* Model 5
svy: reg list treatment fsln plc inc_2 inc_3 inc_4 edu age female I_fsln I_plc I_inc_2 I_inc_3 I_inc_4 I_edu I_age I_female, nolog
estimates store m15

* Model 6
svy: reg list treatment fsln plc inc_2 inc_3 inc_4 edu age female YDKmonitor welfare pubwrk councild zona I_fsln I_plc I_inc_2 I_inc_3 I_inc_4 I_edu I_age I_female I_YDKmonitor I_welfare I_pubwrk I_councild I_urban, nolog
estimates store m16

estout m1* using Table4.txt, ///
	cells(b(star fmt(3)) se(par)) starlevels(* 0.1 ** 0.05 *** 0.01) ///
	stats(N r2_p r2 r2_a, labels("Observations" "Pseudo R^2")) title("Table 4. The instability of traditional estimates of vote buying ") ///
	varlabels(_cons Constant ///
	fsln "supporter of FSLN" plc "supporter of PLC" none "Independents"  inc_2 "Very Poor" inc_3 "Poor" inc_4 "Middle/Upper" edu "Education" age "Age" female "Female" YDKmonitor "Monitor"  welfare "Welfare" pubwrk "Public Works" councild "Citizen Power Council" zona "Urban" ///
	) legend style(tab) replace
	
	/*
		You may need to install the estout package if you do not have it already. 
			Simply type the following line in the Command window:
			. ssc install estout
	
		If you get the following error message when running the estout command line:
			. file Table4.txt could not be opened
			. r(603)
		you just need to set up your working directory
	*/
	
	
		
	/* NOTE TABLE 4:
	* p<0.1, ** p<0.05, *** p<0.01
	Models 1-4 are logistic regressions.  For income, "no answer/refused" 
	is the excluded category, except for Models 1-2, which also excludes 
	the middle/upper income group, since 0 respondents who refused the income 
	item admitted to vote buying at the individual level, thereby necessitating 
	the exclusion of two categories for estimation purposes.  Models 5-6 are 
	OLS regressions with the list experiment count as the dependent variable.  
	For ease of interpretation, all coefficients for models 5-6 are interactions 
	between the independent variable and the list experiment condition 
	(the treatment), since these provide the most comparable estimates.  
	The coefficients for the main independent variables, which predict the number 
	of other items on the list, are omitted but are available upon request.
	*/		
		
		
